package org.maachang.session.server.protocol ;

import org.maachang.util.ArrayBinary;
import org.maachang.util.ConvertParam;

/**
 * 指定セッションID非存在時に新規作成.
 * 
 * @version 2008/05/25
 * @author masahito suzuki
 * @since PersistenceSession 1.00
 */
public class SvUseToSessionIdProtocol extends ServerProtocol {
    
    /**
     * 問合せセッションID.
     */
    private String sessionId = null ;
    
    /**
     * コンストラクタ.
     */
    public SvUseToSessionIdProtocol( byte[] bin,int p )
        throws Exception {
        int len = ConvertParam.convertInt( p,bin ) ;
        p += 4 ;
        if( len > 0 ) {
            byte[] b = new byte[ len ] ;
            System.arraycopy( bin,p,b,0,len ) ;
            this.sessionId = new String( b,"UTF8" ) ;
            p += len ;
        }
        else {
            this.sessionId = null ;
        }
    }
    
    /**
     * サーバプロトコルタイプを取得.
     * @return int サーバプロトコルタイプが返されます.
     */
    public int getProtocolType() {
        return TYPE_USE_TO_SESSOIN_ID ;
    }
    
    /**
     * 問合せセッションIDを取得.
     * @return String 問合せセッションIDが返されます.
     */
    public String getSessionId() {
        return sessionId ;
    }
    
    /**
     * 処理結果の内容を設定.
     * @param value 処理結果の内容を設定します.
     * @exception Exception 例外.
     */
    public void setResult( Object value ) throws Exception {
        ArrayBinary b = new ArrayBinary( 100 ) ;
        b.write( ConvertParam.convertInt( getProtocolType() ) ) ;
        byte[] ss = (( String )value ).getBytes( "UTF8" ) ;
        b.write( ConvertParam.convertInt( ss.length ) ) ;
        b.write( ss ) ;
        ss = null ;
        this.result = b.getBinary() ;
    }
}

